==> pln-2.5.0.tgz: package/ppc/platform/core/lib/util/plane.js <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */

//#ifdef __WITH_PLANE
/**
 * @todo needs refactor
 * @private
 */
apf.plane = {
    $set    : [],
    $lookup : {},
    $find : function(id){
        if (this.$lookup[id])
            return this.$lookup[id];
        
        var item = this.$set.pop();
        if (!item)
            item = this.$factory();
        
        //item.id = id;
        this.$lookup[id] = item;
        
        return item;
    },
    
    get : function(options){
        return this.$find(options && options.protect || "default");
    },
    
    show : function(o, reAppend, copyCursor, useRealSize, options){
        this.options = options || {};
        var item = this.$find(options && options.protect || "default");
        item.show(o, reAppend, copyCursor, useRealSize, options);
    },
    
    hide : function(protect, noAnim){
        var item = this.$lookup[protect || "default"];
        if (item) {
            item.hide(noAnim);
            delete this.$lookup[protect || "default"];
            this.$set.push(item);
        }
    },

    $factory : function(){
        var _self = this,
            spacerPath = "url(" + (apf.skins.skins["default"] 
            ? apf.skins.skins["default"].mediaPath + "spacer.gif" : "images/spacer.gif") + ")";
        
        function getCover(){
            var obj = document.createElement("DIV");
            
            if(!_self.options || !_self.options.customCover)
                return obj;
            
            obj.innerHTML = apf.getXmlString(_self.options.customCover);
            return obj.firstChild;
        }
        
        function createCover(){
            var cover = document.body.appendChild(getCover());
            if(!_self.options.customCover)
                cover.style.background = spacerPath;

            cover.style.position = "fixed";
            cover.style.left     = 0;
            cover.style.top      = 0;
            cover.host           = false;
            
            return cover;
        }
        
        var plane = createCover();
        
        return {
            host          : this,
            plane         : plane,
            lastCursor    : null,
            lastCoverType :"default",
            
            show : function(o, reAppend, copyCursor, useRealSize, options){
                var coverType = options && options.customCover ? "custom" : "default",
                    plane;
                
                if (coverType == "custom" || this.lastCoverType != coverType)
                    this.plane = createCover();
                
                plane = this.plane;
            
                if(!options || !options.customCover)
                    this.plane.style.background = options && options.color || spacerPath;
                
                this.animate = options && options.animate;
                this.protect = options && options.protect;
                
                if (this.protect)
                    apf.setProperty("planes", (apf.planes || 0) + 1);
                
                if (o) { //@experimental
                    this.current = o;
                    if (reAppend) { 
                        this.$originalPlace = [o.parentNode, o.nextSibling];
                        this.plane.appendChild(o);
                    }
                }
                apf.window.zManager.set("plane", this.plane, !reAppend && o);
                
                useRealSize = apf.isIE;
                var pWidth = (plane.parentNode == document.body
                    ? useRealSize ? document.documentElement.offsetWidth : apf.getWindowWidth()
                    : plane.parentNode.offsetWidth);
         
                var pHeight = (plane.parentNode == document.body
                    ? useRealSize ? document.documentElement.offsetHeight : apf.getWindowHeight()
                    : plane.parentNode.offsetHeight);
                
                if (copyCursor) {
                    if (this.lastCursor === null)
                        this.lastCursor = document.body.style.cursor;
                    document.body.style.cursor = apf.getStyle(o, "cursor");
                }
                
                this.plane.style.display = "block";
                //this.plane.style.left    = p.scrollLeft;
                //this.plane.style.top     = p.scrollTop;
                
                var toOpacity = parseFloat(options && options.opacity) || 1;
                if (this.animate) {
                    var _self = this;
                    apf.setOpacity(this.plane, 0);
                    setTimeout(function(){
                        apf.tween.single(_self.plane, {
                            steps    : 5,
                            interval : 10,
                            type     : "fade",
                            from     : 0,
                            to       : toOpacity
                        });
                    }, 100);
                }
                else
                    apf.setOpacity(this.plane, toOpacity);
                
                var diff = apf.getDiff(plane);
                this.plane.style.width  = "100%";//(pWidth - diff[0]) + "px";
                this.plane.style.height = "100%";//(pHeight - diff[1]) + "px";
        
                this.lastCoverType = options && options.customCover ? "custom" : "default";
        
                return plane;
            },
        
            hide : function(noAnim){
                if (this.protect)
                    apf.setProperty("planes", apf.planes - 1);
                
                var isChild; // try...catch block is needed to work around a FF3 Win issue with HTML elements
                try {
                    isChild = apf.isChildOf(this.plane, document.activeElement);
                }
                catch (ex) {
                    isChild = false;
                }
                if (this.current && this.current.parentNode == this.plane)
                    this.$originalPlace[0].insertBefore(this.current, this.$originalPlace[1]);
                
                if (this.animate && !noAnim) {
                    var _self = this;
                    setTimeout(function(){
                        apf.tween.single(_self.plane, {
                            steps    : 5,
                            interval : 10,
                            type     : "fade",
                            from     : apf.getOpacity(_self.plane),
                            to       : 0,
                            onfinish : function(){
                                _self.plane.style.display  = "none";
                                
                                if (_self.current)
                                    apf.window.zManager.clear(_self.current);
                            }
                        });
                    }, 100);
                }
                else {
                    apf.setOpacity(this.plane, 0);
                    if (this.current)
                        apf.window.zManager.clear(this.plane, this.current);
                    this.plane.style.display  = "none";
                }
                
                if (isChild && apf.document.activeElement) {
                    if (!apf.isIE)
                        document.activeElement.focus();
                    apf.document.activeElement.$focus();
                }
                
                this.current = null;
                
                if (this.lastCursor !== null) {
                    document.body.style.cursor = this.lastCursor;
                    this.lastCursor = null;
                }
                
                return this.plane;
            }
        };
    }
};
//#endif

==> pln-2.9.0.tgz: package/ppc/platform/core/lib/util/plane.js <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 *
 */

//#ifdef __WITH_PLANE
/**
 * @todo needs refactor
 * @private
 */
ppc.plane = {
    $set    : [],
    $lookup : {},
    $find : function(id){
        if (this.$lookup[id])
            return this.$lookup[id];
        
        var item = this.$set.pop();
        if (!item)
            item = this.$factory();
        
        //item.id = id;
        this.$lookup[id] = item;
        
        return item;
    },
    
    get : function(options){
        return this.$find(options && options.protect || "default");
    },
    
    show : function(o, reAppend, copyCursor, useRealSize, options){
        this.options = options || {};
        var item = this.$find(options && options.protect || "default");
        item.show(o, reAppend, copyCursor, useRealSize, options);
    },
    
    hide : function(protect, noAnim){
        var item = this.$lookup[protect || "default"];
        if (item) {
            item.hide(noAnim);
            delete this.$lookup[protect || "default"];
            this.$set.push(item);
        }
    },

    $factory : function(){
        var _self = this,
            spacerPath = "url(" + (ppc.skins.skins["default"] 
            ? ppc.skins.skins["default"].mediaPath + "spacer.gif" : "images/spacer.gif") + ")";
        
        function getCover(){
            var obj = document.createElement("DIV");
            
            if(!_self.options || !_self.options.customCover)
                return obj;
            
            obj.innerHTML = ppc.getXmlString(_self.options.customCover);
            return obj.firstChild;
        }
        
        function createCover(){
            var cover = document.body.appendChild(getCover());
            if(!_self.options.customCover)
                cover.style.background = spacerPath;

            cover.style.position = "fixed";
            cover.style.left     = 0;
            cover.style.top      = 0;
            cover.host           = false;
            
            return cover;
        }
        
        var plane = createCover();
        
        return {
            host          : this,
            plane         : plane,
            lastCursor    : null,
            lastCoverType :"default",
            
            show : function(o, reAppend, copyCursor, useRealSize, options){
                var coverType = options && options.customCover ? "custom" : "default",
                    plane;
                
                if (coverType == "custom" || this.lastCoverType != coverType)
                    this.plane = createCover();
                
                plane = this.plane;
            
                if(!options || !options.customCover)
                    this.plane.style.background = options && options.color || spacerPath;
                
                this.animate = options && options.animate;
                this.protect = options && options.protect;
                
                if (this.protect)
                    ppc.setProperty("planes", (ppc.planes || 0) + 1);
                
                if (o) { //@experimental
                    this.current = o;
                    if (reAppend) { 
                        this.$originalPlace = [o.parentNode, o.nextSibling];
                        this.plane.appendChild(o);
                    }
                }
                ppc.window.zManager.set("plane", this.plane, !reAppend && o);
                
                useRealSize = ppc.isIE;
                var pWidth = (plane.parentNode == document.body
                    ? useRealSize ? document.documentElement.offsetWidth : ppc.getWindowWidth()
                    : plane.parentNode.offsetWidth);
         
                var pHeight = (plane.parentNode == document.body
                    ? useRealSize ? document.documentElement.offsetHeight : ppc.getWindowHeight()
                    : plane.parentNode.offsetHeight);
                
                if (copyCursor) {
                    if (this.lastCursor === null)
                        this.lastCursor = document.body.style.cursor;
                    document.body.style.cursor = ppc.getStyle(o, "cursor");
                }
                
                this.plane.style.display = "block";
                //this.plane.style.left    = p.scrollLeft;
                //this.plane.style.top     = p.scrollTop;
                
                var toOpacity = parseFloat(options && options.opacity) || 1;
                if (this.animate) {
                    var _self = this;
                    ppc.setOpacity(this.plane, 0);
                    setTimeout(function(){
                        ppc.tween.single(_self.plane, {
                            steps    : 5,
                            interval : 10,
                            type     : "fade",
                            from     : 0,
                            to       : toOpacity
                        });
                    }, 100);
                }
                else
                    ppc.setOpacity(this.plane, toOpacity);
                
                var diff = ppc.getDiff(plane);
                this.plane.style.width  = "100%";//(pWidth - diff[0]) + "px";
                this.plane.style.height = "100%";//(pHeight - diff[1]) + "px";
        
                this.lastCoverType = options && options.customCover ? "custom" : "default";
        
                return plane;
            },
        
            hide : function(noAnim){
                if (this.protect)
                    ppc.setProperty("planes", ppc.planes - 1);
                
                var isChild; // try...catch block is needed to work around a FF3 Win issue with HTML elements
                try {
                    isChild = ppc.isChildOf(this.plane, document.activeElement);
                }
                catch (ex) {
                    isChild = false;
                }
                if (this.current && this.current.parentNode == this.plane)
                    this.$originalPlace[0].insertBefore(this.current, this.$originalPlace[1]);
                
                if (this.animate && !noAnim) {
                    var _self = this;
                    setTimeout(function(){
                        ppc.tween.single(_self.plane, {
                            steps    : 5,
                            interval : 10,
                            type     : "fade",
                            from     : ppc.getOpacity(_self.plane),
                            to       : 0,
                            onfinish : function(){
                                _self.plane.style.display  = "none";
                                
                                if (_self.current)
                                    ppc.window.zManager.clear(_self.current);
                            }
                        });
                    }, 100);
                }
                else {
                    ppc.setOpacity(this.plane, 0);
                    if (this.current)
                        ppc.window.zManager.clear(this.plane, this.current);
                    this.plane.style.display  = "none";
                }
                
                if (isChild && ppc.document.activeElement) {
                    if (!ppc.isIE)
                        document.activeElement.focus();
                    ppc.document.activeElement.$focus();
                }
                
                this.current = null;
                
                if (this.lastCursor !== null) {
                    document.body.style.cursor = this.lastCursor;
                    this.lastCursor = null;
                }
                
                return this.plane;
            }
        };
    }
};
//#endif
